@@ -830,7 +830,7 @@ mod vec4 {
     fn test_align() {
         use std::mem;
         assert_eq!(16, mem::size_of::<Vec4>());
-        if cfg!(feature = "scalar-math") {
+        if cfg!(any(not(target_feature = "sse2"), feature = "scalar-math")) {
             assert_eq!(4, mem::align_of::<Vec4>());
             assert_eq!(4, mem::size_of::<Vec4Mask>());
             assert_eq!(1, mem::align_of::<Vec4Mask>());
@@ -934,7 +934,7 @@ mod dvec4 {
     fn test_align() {
         use std::mem;
         assert_eq!(32, mem::size_of::<DVec4>());
-        assert_eq!(8, mem::align_of::<DVec4>());
+        assert_eq!(mem::align_of::<f64>(), mem::align_of::<DVec4>());
         assert_eq!(4, mem::size_of::<BVec4>());
         assert_eq!(1, mem::align_of::<BVec4>());
     }
